@@ -1,8 +1,9 @@
 from __future__ import absolute_import
+from functools import wraps
 import sys
 
 
-__version__ = '0.11.8'
+__version__ = '0.12.1'
 
 # Python 2 vs 3
 PY3 = sys.version_info[0] == 3
@@ -18,6 +19,24 @@ else:
     from future_builtins import map
     builtins = __builtins__
 
+    from logging import Logger
+    def hasHandlers(self):
+        """
+        logging backport from Python 3.2
+        """
+        c = self
+        rv = False
+        while c:
+            if c.handlers:
+                rv = True
+                break
+            if not c.propagate:
+                break
+            else:
+                c = c.parent
+        return rv
+    Logger.hasHandlers = hasHandlers
+
 # Platform specifics
 if sys.platform.startswith('win'):
     from . import _xlwindows as xlplatform
@@ -38,25 +57,33 @@ from .main import apps, books, sheets
 if sys.platform.startswith('win'):
     from .udfs import xlfunc as func, xlsub as sub, xlret as ret, xlarg as arg, get_udf_module, import_udfs
 else:
-    def func(*args, **kwargs):
-        def real_decorator(f):
+    def func(f=None, *args, **kwargs):
+        @wraps(f)
+        def inner(f):
             return f
-        return real_decorator
+        if f is None:
+            return inner
+        else:
+            return inner(f)
 
-    def sub(*args, **kwargs):
-        def real_decorator(f):
+    def sub(f=None, *args, **kwargs):
+        @wraps(f)
+        def inner(f):
             return f
-        return real_decorator
+        if f is None:
+            return inner
+        else:
+            return inner(f)
 
     def ret(*args, **kwargs):
-        def real_decorator(f):
+        def inner(f):
             return f
-        return real_decorator
+        return inner
 
     def arg(*args, **kwargs):
-        def real_decorator(f):
+        def inner(f):
             return f
-        return real_decorator
+        return inner
 
 
 def xlfunc(*args, **kwargs):
